==> TuxGuitar-0.8-src.tar.gz: TuxGuitar-0.8-src/src/org/herac/tuxguitar/gui/actions/duration/ChangeDoubleDottedDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.TablatureEditor;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.component.UndoableComponentGeneric;
import org.herac.tuxguitar.song.models.Duration;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class ChangeDoubleDottedDurationAction extends Action{
    public static final String NAME = "CHANGE_DOUBLE_DOTTED_DURATION";
    
    public ChangeDoubleDottedDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) { 
        //comienza el undoable
    	UndoableComponentGeneric undoable = UndoableComponentGeneric.startUndo(); 
    	
        getSelectedDuration().setDoubleDotted(!getSelectedDuration().isDoubleDotted());
        getSelectedDuration().setDotted(false);
        
        setDurations();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());  
        
        return true;
    }

    private void setDurations() {                
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();        
    }    
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }    

}

==> TuxGuitar-0.9-src.tar.gz: TuxGuitar-0.9-src/src/org/herac/tuxguitar/gui/actions/duration/ChangeDoubleDottedDurationAction.java <==
/*
 * Created on 17-dic-2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package org.herac.tuxguitar.gui.actions.duration;

import org.eclipse.swt.events.TypedEvent;
import org.herac.tuxguitar.gui.actions.Action;
import org.herac.tuxguitar.gui.editors.TablatureEditor;
import org.herac.tuxguitar.gui.editors.tab.Caret;
import org.herac.tuxguitar.gui.undo.undoables.measure.UndoableMeasureGeneric;
import org.herac.tuxguitar.song.models.Duration;

/**
 * @author julian
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class ChangeDoubleDottedDurationAction extends Action{
    public static final String NAME = "action.note.duration.change-double-dotted";
    
    public ChangeDoubleDottedDurationAction(TablatureEditor tablatureEditor) {
        super(NAME,true,tablatureEditor);       
    }

    public boolean doAction(TypedEvent e) { 
        //comienza el undoable
    	UndoableMeasureGeneric undoable = UndoableMeasureGeneric.startUndo(); 
    	
        getSelectedDuration().setDoubleDotted(!getSelectedDuration().isDoubleDotted());
        getSelectedDuration().setDotted(false);
        
        setDurations();     
        
        //termia el undoable
        getEditor().getUndoManager().addEdit(undoable.endUndo());  
        
        return true;
    }

    private void setDurations() {                
        Caret caret = getEditor().getTablature().getCaret();            
        caret.changeDuration((Duration)getSelectedDuration().clone());
        fireUpdate(getEditor().getTablature().getCaret().getMeasureCoords().getMeasure().getNumber());
        redraw();        
    }    
    
    public Duration getSelectedDuration(){
        return getEditor().getTablature().getCaret().getDuration();
    }    

}
